Enum trillium_http::ConnectionStatus
source · pub enum ConnectionStatus<Transport> {
Close,
Conn(Conn<Transport>),
Upgrade(Upgrade<Transport>),
}Expand description
This represents the next state after a response on a conn transport.
Variants
Close
The transport has been closed, either by the client or by us
Conn(Conn<Transport>)
Another Conn request has been sent on the same transport and
is ready to respond to. This can occur any number of times and
should be handled in a loop.
Upgrade(Upgrade<Transport>)
An http upgrade has been negotiated. This is always a terminal state for a given connection.