H3ErrorCode

Enum H3ErrorCode 

#[non_exhaustive]
pub enum H3ErrorCode {
Show 25 variants NoError = 256, GeneralProtocolError = 257, InternalError = 258, StreamCreationError = 259, ClosedCriticalStream = 260, FrameUnexpected = 261, FrameError = 262, ExcessiveLoad = 263, IdError = 264, SettingsError = 265, MissingSettings = 266, RequestRejected = 267, RequestCancelled = 268, RequestIncomplete = 269, MessageError = 270, ConnectError = 271, VersionFallback = 272, WebTransportBufferedStreamRejected = 966_049_156, WebTransportSessionGone = 386_759_528, WebTransportFlowControlError = 73_221_255, WebTransportAlpnError = 135_771_101, WebTransportRequirementsNotMet = 556_535_112, QpackDecompressionFailed = 512, QpackEncoderStreamError = 513, QpackDecoderStreamError = 514,
}
H3 error codes (RFC 9114).

Used when closing connections or resetting streams. Unknown error codes decode as NoError.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoError = 256

No error. Used when closing without an error to signal.



GeneralProtocolError = 257

Peer violated protocol requirements.



InternalError = 258

An internal error in the HTTP stack.



StreamCreationError = 259

Peer created a stream that will not be accepted.



ClosedCriticalStream = 260

A required stream was closed or reset.



FrameUnexpected = 261

A frame was not permitted in the current state or stream.



FrameError = 262

A frame fails layout requirements or has an invalid size.



ExcessiveLoad = 263

Peer is generating excessive load.



IdError = 264

A stream ID or push ID was used incorrectly.



SettingsError = 265

Error in the payload of a SETTINGS frame.



MissingSettings = 266

No SETTINGS frame at the beginning of the control stream.



RequestRejected = 267

Server rejected a request without application processing.



RequestCancelled = 268

Request or response (including pushed) is cancelled.



RequestIncomplete = 269

Client stream terminated without a fully formed request.



MessageError = 270

HTTP message was malformed.



ConnectError = 271

TCP connection for CONNECT was reset or abnormally closed.



VersionFallback = 272

Requested operation cannot be served over HTTP/3.



WebTransportBufferedStreamRejected = 966_049_156

WebTransport data stream rejected due to lack of associated session.



WebTransportSessionGone = 386_759_528

WebTransport data stream or session closed because the associated session is gone.



WebTransportFlowControlError = 73_221_255

WebTransport session flow control error.



WebTransportAlpnError = 135_771_101

WebTransport application protocol negotiation failed.



WebTransportRequirementsNotMet = 556_535_112

Required WebTransport settings or transport parameters not met.



QpackDecompressionFailed = 512

The decoder failed to interpret a header block.



QpackEncoderStreamError = 513

The decoder failed to interpret an encoder stream instruction.



QpackDecoderStreamError = 514

The encoder failed to interpret a decoder stream instruction.

Implementations

Source

impl H3ErrorCode

pub fn reason(&self) -> Cow<'static, str>

A “reason phrase” suitable for inclusion in a CONNECTION_CLOSE frame.

pub fn is_connection_error(&self) -> bool

Returns true if this error code represents a connection-level error that requires closing the entire QUIC connection (via CONNECTION_CLOSE).

Returns false for stream-level errors such as Self::MessageError or Self::RequestIncomplete, which should reset the individual stream rather than tear down the whole connection.